@@ -51,7 +51,7 @@ papi_vector_t _net_vector;
 #define NET_INVALID_RESULT     -1
 
 
-static NET_native_event_entry_t * _net_native_events;
+static NET_native_event_entry_t * _net_native_events=NULL;
 
 static int num_events       = 0;
 static int is_initialized   = 0;
@@ -324,8 +324,10 @@ _net_init_component( int cidx  )
     _net_native_events = (NET_native_event_entry_t*)
         papi_malloc(sizeof(NET_native_event_entry_t) * num_events);
     do {
-        strncpy(_net_native_events[i].name, t->name, PAPI_MAX_STR_LEN);
-        strncpy(_net_native_events[i].description, t->description, PAPI_MAX_STR_LEN);
+        strncpy(_net_native_events[i].name, t->name, PAPI_MAX_STR_LEN-1);
+        _net_native_events[i].name[PAPI_MAX_STR_LEN-1] = '\0';
+        strncpy(_net_native_events[i].description, t->description, PAPI_MAX_STR_LEN-1);
+        _net_native_events[i].description[PAPI_MAX_STR_LEN-1] = '\0';
         _net_native_events[i].resources.selector = i + 1;
         last    = t;
         t       = t->next;
@@ -444,10 +446,14 @@ _net_shutdown_thread( hwd_context_t *ctx )
 int
 _net_shutdown_component( void )
 {
-    if ( is_initialized ) {
-        is_initialized = 0;
-        papi_free(_net_native_events);
-        _net_native_events = NULL;
+    if ( is_initialized )
+    {
+      is_initialized = 0;
+      if (_net_native_events != NULL)
+      {
+         papi_free(_net_native_events);
+         _net_native_events = NULL;
+      }
     }
 
     return PAPI_OK;
