@@ -3,6 +3,14 @@
 *
 * Author:  Vince Weaver
 *          vincent.weaver@maine.edu
+* Mods:    Gary Mohr
+*          gary.mohr@bull.com
+*          Modified the perf_event_uncore component to use PFM_OS_PERF_EVENT_EXT mode in libpfm4.
+*          This adds several new event masks, including cpu=, u=, and k= which give the user
+*          the ability to set cpu number to use or control the domain (user, kernel, or both)
+*          in which the counter should be incremented.  These are event masks so it is now
+*          possible to have multiple events in the same event set that count activity from
+*          differennt cpu's or count activity in different domains.
 */
 
 #include <fcntl.h>
@@ -42,11 +50,50 @@ papi_vector_t _perf_event_uncore_vector;
 /* Globals */
 struct native_event_table_t uncore_native_event_table;
 static int our_cidx;
+int
+_peu_libpfm4_get_cidx() {
+	return our_cidx;
+}
 
 /* Defines for ctx->state */
 #define PERF_EVENTS_OPENED  0x01
 #define PERF_EVENTS_RUNNING 0x02
 
+static int _peu_set_domain( hwd_control_state_t *ctl, int domain);
+
+
+
+/******************************************************************/
+/******** Kernel Version Dependent Routines  **********************/
+/******************************************************************/
+
+/* KERNEL_CHECKS_SCHEDUABILITY_UPON_OPEN is a work-around for kernel arch
+ * implementations (e.g. x86) which don't do a static event scheduability
+ * check in sys_perf_event_open.
+ * This was fixed for x86 in the 2.6.33 kernel
+ *
+ * Also! Kernels newer than 2.6.34 will fail in a similar way
+ *       if the nmi_watchdog has stolen a performance counter
+ *       and we try to use the maximum number of counters.
+ *       A sys_perf_event_open() will seem to succeed but will fail
+ *       at read time.  So re-use this work around code.
+ */
+static int
+bug_check_scheduability(void) {
+
+#if defined(__powerpc__)
+   /* PowerPC not affected by this bug */
+#elif defined(__mips__)
+   /* MIPS as of kernel 3.1 does not properly detect schedulability */
+   return 1;
+#else
+   if (_papi_os_info.os_version < LINUX_VERSION(2,6,33))
+	return 1;
+#endif
+
+   return 0;
+}
+
 
 /* The read format on perf_event varies based on various flags that */
 /* are passed into it.  This helper avoids copying this logic       */
@@ -77,6 +124,10 @@ get_read_format( unsigned int multiplex,
    return format;
 }
 
+/*****************************************************************/
+/********* End Kernel-version Dependent Routines  ****************/
+/*****************************************************************/
+
 /********************************************************************/
 /* Low-level perf_event calls                                       */
 /********************************************************************/
@@ -102,24 +153,6 @@ sys_perf_event_open( struct perf_event_attr *hw_event, pid_t pid, int cpu,
 {
    int ret;
 
-// If the comments on the following define symbol are removed, then applications that do not pass 
-// cpu numbers can be used with uncore events.  They will always get counts from the package which 
-// contains cpu 0 but at least they will work.  For instance this allows you to do uncore event testing 
-// with the papi_command_line utility.  But normally the cpu number to identify which package should 
-// be counted should be provided by the papi application so this should be commented out by default.
-// #define UNCORE_HELP 1
-#ifdef UNCORE_HELP
-   // A cpu number of -1 normally indicates that the caller does not want to limit counting to a specified cpu.
-   // But if a negative cpu number is passed to the kernel when counting uncore events, it will return an
-   // invalid argument error so we force the cpu number to zero in this case.  In uncore the cpu number is
-   // used by the kernel to specify which package should be counted so this code will set the default for
-   // counting uncore events to the package that contains cpu 0 (when not specified by the calling
-   // applicaiton).  Since uncore events are not associated with any cpu, it really does not matter
-   // which cpu number is used as a default.
-   if (cpu < 0)
-     cpu = 0;
-#endif
-
    SUBDBG("sys_perf_event_open(hw_event: %p, pid: %d, cpu: %d, group_fd: %d, flags: %lx\n",hw_event,pid,cpu,group_fd,flags);
    SUBDBG("   type: %d\n",hw_event->type);
    SUBDBG("   size: %d\n",hw_event->size);
@@ -158,8 +191,7 @@ sys_perf_event_open( struct perf_event_attr *hw_event, pid_t pid, int cpu,
    SUBDBG("   sample_regs_user: %lu\n",hw_event->sample_regs_user);
    SUBDBG("   sample_stack_user: %d\n",hw_event->sample_stack_user);
 
-	ret =
-		syscall( __NR_perf_event_open, hw_event, pid, cpu, group_fd, flags );
+	ret = syscall( __NR_perf_event_open, hw_event, pid, cpu, group_fd, flags );
 	SUBDBG("Returned %d %d %s\n",ret,
 	       ret<0?errno:0,
 	       ret<0?strerror(errno):" ");
@@ -210,6 +242,90 @@ static int map_perf_event_errors_to_papi(int perf_event_error) {
 /*  possible counter value.                                   */
 #define READ_BUFFER_SIZE (3 + (2 * PERF_EVENT_MAX_MPX_COUNTERS))
 
+
+
+/* KERNEL_CHECKS_SCHEDUABILITY_UPON_OPEN is a work-around for kernel arch */
+/* implementations (e.g. x86 before 2.6.33) which don't do a static event */
+/* scheduability check in sys_perf_event_open.  It is also needed if the  */
+/* kernel is stealing an event, such as when NMI watchdog is enabled.     */
+
+static int
+check_scheduability( pe_context_t *ctx, pe_control_t *ctl)
+{
+   SUBDBG("ENTER: ctx: %p, ctl: %p\n", ctx, ctl);
+   int retval = 0, cnt = -1;
+   ( void ) ctx;	     /*unused */
+   long long papi_pe_buffer[READ_BUFFER_SIZE];
+   int i;
+
+   if (bug_check_scheduability()) {
+
+	/* If the kernel isn't tracking scheduability right       */
+	/* Then we need to start/stop/read to force the event     */
+	/* to be scheduled and see if an error condition happens. */
+
+	/* start all events */
+	for( i = 0; i < ctl->num_events; i++) {
+	    retval = ioctl( ctl->events[i].event_fd, PERF_EVENT_IOC_ENABLE, NULL );
+	    if (retval == -1) {
+		SUBDBG("EXIT: Enable failed event index: %d, num_events: %d, return PAPI_ESYS\n", i, ctl->num_events);
+		return PAPI_ESYS;
+	    }
+	}
+
+	/* stop all events */
+	for( i = 0; i < ctl->num_events; i++) {
+	    retval = ioctl(ctl->events[i].event_fd, PERF_EVENT_IOC_DISABLE, NULL );
+	    if (retval == -1) {
+		SUBDBG("EXIT: Disable failed: event index: %d, num_events: %d, return PAPI_ESYS\n", i, ctl->num_events);
+		return PAPI_ESYS;
+	    }
+	}
+
+	/* See if a read of each event returns results */
+	for( i = 0; i < ctl->num_events; i++) {
+	    cnt = read( ctl->events[i].event_fd, papi_pe_buffer, sizeof(papi_pe_buffer));
+	    if ( cnt == -1 ) {
+		SUBDBG( "EXIT: read failed: event index: %d, num_events: %d, return PAPI_ESYS.  Should never happen.\n", i, ctl->num_events);
+		return PAPI_ESYS;
+	    }
+
+	    if ( cnt == 0 ) {
+		/* We read 0 bytes if we could not schedule the event */
+		/* The kernel should have detected this at open       */
+		/* but various bugs (including NMI watchdog)          */
+		/* result in this behavior                            */
+
+		SUBDBG( "EXIT: read returned 0: event index: %d, num_events: %d, return PAPI_ECNFLCT.\n", i, ctl->num_events);
+		return PAPI_ECNFLCT;
+	    }
+	}
+
+	/* Reset all of the counters (opened so far) back to zero      */
+	/* from the above brief enable/disable call pair.              */
+
+	/* We have to reset all events because reset of group leader      */
+	/* does not reset all.                                            */
+	/* we assume that the events are being added one by one and that  */
+	/* we do not need to reset higher events (doing so may reset ones */
+	/* that have not been initialized yet.                            */
+
+	/* Note... PERF_EVENT_IOC_RESET does not reset time running       */
+	/* info if multiplexing, so we should avoid coming here if        */
+	/* we are multiplexing the event.                                 */
+	for( i = 0; i < ctl->num_events; i++) {
+	    retval=ioctl( ctl->events[i].event_fd, PERF_EVENT_IOC_RESET, NULL );
+	    if (retval == -1) {
+		SUBDBG("EXIT: Reset failed: event index: %d, num_events: %d, return PAPI_ESYS\n", i, ctl->num_events);
+		return PAPI_ESYS;
+	    }
+	}
+   }
+   SUBDBG("EXIT: return PAPI_OK\n");
+   return PAPI_OK;
+}
+
+
 /* Open all events in the control state */
 static int
 open_pe_events( pe_context_t *ctx, pe_control_t *ctl )
@@ -285,7 +401,7 @@ open_pe_events( pe_context_t *ctx, pe_control_t *ctl )
       /* try to open */
       ctl->events[i].event_fd = sys_perf_event_open( &ctl->events[i].attr,
 						     pid,
-						     ctl->cpu,
+						     ctl->events[i].cpu,
 			       ctl->events[i].group_leader_fd,
 						     0 /* flags */
 						     );
@@ -297,18 +413,37 @@ open_pe_events( pe_context_t *ctx, pe_control_t *ctl )
 		i, strerror( errno ) );
          ret=map_perf_event_errors_to_papi(errno);
 
-	 goto open_pe_cleanup;
+    goto open_peu_cleanup;
       }
 
       SUBDBG ("sys_perf_event_open: tid: %ld, cpu_num: %d,"
               " group_leader/fd: %d, event_fd: %d,"
-              " read_format: %#"PRIu64"\n",
-	      pid, ctl->cpu, ctl->events[i].group_leader_fd, 
+              " read_format: %"PRIu64"\n",
+	      pid, ctl->events[i].cpu, ctl->events[i].group_leader_fd,
 	      ctl->events[i].event_fd, ctl->events[i].attr.read_format);
 
       ctl->events[i].event_opened=1;
    }
 
+
+   /* in many situations the kernel will indicate we opened fine */
+   /* yet things will fail later.  So we need to double check    */
+   /* we actually can use the events we've set up.               */
+
+   /* This is not necessary if we are multiplexing, and in fact */
+   /* we cannot do this properly if multiplexed because         */
+   /* PERF_EVENT_IOC_RESET does not reset the time running info */
+   if (!ctl->multiplexed) {
+	ret = check_scheduability( ctx, ctl);
+
+	if ( ret != PAPI_OK ) {
+	    /* the last event did open, so we need to bump the counter */
+	    /* before doing the cleanup                                */
+	    i++;
+	    goto open_peu_cleanup;
+	}
+   }
+
    /* Now that we've successfully opened all of the events, do whatever  */
    /* "tune-up" is needed to attach the mmap'd buffers, signal handlers, */
    /* and so on.                                                         */
@@ -323,7 +458,7 @@ open_pe_events( pe_context_t *ctx, pe_control_t *ctl )
 
    return PAPI_OK;
 
-open_pe_cleanup:
+open_peu_cleanup:
    /* We encountered an error, close up the fds we successfully opened.  */
    /* We go backward in an attempt to close group leaders last, although */
    /* That's probably not strictly necessary.                            */
@@ -462,7 +597,7 @@ _peu_init_control_state( hwd_control_state_t *ctl )
   memset( pe_ctl, 0, sizeof ( pe_control_t ) );
 
   /* Set the default domain */
-  _pe_set_domain( ctl, _perf_event_uncore_vector.cmp_info.default_domain );
+  _peu_set_domain( ctl, _perf_event_uncore_vector.cmp_info.default_domain );
 
   /* Set the default granularity */
   pe_ctl->granularity=_perf_event_uncore_vector.cmp_info.default_granularity;
@@ -555,7 +690,7 @@ _peu_init_component( int cidx )
 int _peu_shutdown_component( void ) {
 
   /* deallocate our event table */
-  _peu_libpfm4_shutdown(&uncore_native_event_table);
+  _peu_libpfm4_shutdown(&_perf_event_uncore_vector, &uncore_native_event_table);
 
   /* Shutdown libpfm4 */
   _papi_libpfm4_shutdown();
@@ -572,7 +707,11 @@ _peu_update_control_state( hwd_control_state_t *ctl,
 			       NativeInfo_t *native,
 			       int count, hwd_context_t *ctx )
 {
-   int i = 0, ret;
+	int i;
+	int j;
+	int ret;
+	int skipped_events=0;
+	struct native_event_t *ntv_evt;
    pe_context_t *pe_ctx = ( pe_context_t *) ctx;
    pe_control_t *pe_ctl = ( pe_control_t *) ctl;
 
@@ -591,32 +730,81 @@ _peu_update_control_state( hwd_control_state_t *ctl,
    /* set up all the events */
    for( i = 0; i < count; i++ ) {
       if ( native ) {
-	 /* Have libpfm4 set the config values for the event */
-	 ret=_peu_libpfm4_setup_counters(&pe_ctl->events[i].attr,
-					native[i].ni_event,
-					pe_ctx->event_table);
-	 SUBDBG( "pe_ctl->eventss[%d].config=%#"PRIx64"\n",i,
-		 pe_ctl->events[i].attr.config);
-	 if (ret!=PAPI_OK) return ret;
+			// get the native event pointer used for this papi event
+			int ntv_idx = _papi_hwi_get_ntv_idx((unsigned)(native[i].ni_papi_code));
+			if (ntv_idx < -1) {
+				SUBDBG("papi_event_code: %#x known by papi but not by the component\n", native[i].ni_papi_code);
+				continue;
+			}
+			// if native index is -1, then we have an event without a mask and need to find the right native index to use
+			if (ntv_idx == -1) {
+				// find the native event index we want by matching for the right papi event code
+				for (j=0 ; j<pe_ctx->event_table->num_native_events ; j++) {
+					if (pe_ctx->event_table->native_events[j].papi_event_code == native[i].ni_papi_code) {
+						ntv_idx = j;
+					}
+				}
+			}
 
+			// if native index is still negative, we did not find event we wanted so just return error
+			if (ntv_idx < 0) {
+				SUBDBG("papi_event_code: %#x not found in native event tables\n", native[i].ni_papi_code);
+				continue;
+			}
+
+			// this native index is positive so there was a mask with the event, the ntv_idx identifies which native event to use
+			ntv_evt = (struct native_event_t *)(&(pe_ctx->event_table->native_events[ntv_idx]));
+
+			SUBDBG("ntv_evt: %p\n", ntv_evt);
+
+			SUBDBG("i: %d, pe_ctx->event_table->num_native_events: %d\n", i, pe_ctx->event_table->num_native_events);
+
+	    	// Move this events hardware config values and other attributes to the perf_events attribute structure
+			memcpy (&pe_ctl->events[i].attr, &ntv_evt->attr, sizeof(perf_event_attr_t));
+
+			// may need to update the attribute structure with information from event set level domain settings (values set by PAPI_set_domain)
+			// only done if the event mask which controls each counting domain was not provided
+
+			// get pointer to allocated name, will be NULL when adding preset events to event set
+			char *aName = ntv_evt->allocated_name;
+			if ((aName == NULL)  ||  (strstr(aName, ":u=") == NULL)) {
+				SUBDBG("set exclude_user attribute from eventset level domain flags, encode: %d, eventset: %d\n", pe_ctl->events[i].attr.exclude_user, !(pe_ctl->domain & PAPI_DOM_USER));
+				pe_ctl->events[i].attr.exclude_user = !(pe_ctl->domain & PAPI_DOM_USER);
+			}
+			if ((aName == NULL)  ||  (strstr(aName, ":k=") == NULL)) {
+				SUBDBG("set exclude_kernel attribute from eventset level domain flags, encode: %d, eventset: %d\n", pe_ctl->events[i].attr.exclude_kernel, !(pe_ctl->domain & PAPI_DOM_KERNEL));
+				pe_ctl->events[i].attr.exclude_kernel = !(pe_ctl->domain & PAPI_DOM_KERNEL);
+			}
+
+			// set the cpu number provided with an event mask if there was one (will be -1 if mask not provided)
+			pe_ctl->events[i].cpu = ntv_evt->cpu;
+			// if cpu event mask not provided, then set the cpu to use to what may have been set on call to PAPI_set_opt (will still be -1 if not called)
+			if (pe_ctl->events[i].cpu == -1) {
+				pe_ctl->events[i].cpu = pe_ctl->cpu;
+			}
       } else {
-	  /* I'm not sure how we'd end up in this case */
-          /* should it be an error?                    */
+    	  // This case happens when called from _pe_set_overflow and _pe_ctl
+          // Those callers put things directly into the pe_ctl structure so it is already set for the open call
       }
 
-      /* Copy the inherit flag into the attribute block that will be   */
-      /* passed to the kernel */
+      // Copy the inherit flag into the attribute block that will be passed to the kernel
       pe_ctl->events[i].attr.inherit = pe_ctl->inherit;
 
       /* Set the position in the native structure */
       /* We just set up events linearly           */
       if ( native ) {
-	 native[i].ni_position = i;
+    	  native[i].ni_position = i;
+    	  SUBDBG( "&native[%d]: %p, ni_papi_code: %#x, ni_event: %#x, ni_position: %d, ni_owners: %d\n",
+			i, &(native[i]), native[i].ni_papi_code, native[i].ni_event, native[i].ni_position, native[i].ni_owners);
       }
    }
 
-   pe_ctl->num_events = count;
-   _pe_set_domain( ctl, pe_ctl->domain );
+	if (count <= skipped_events) {
+		SUBDBG("EXIT: No events to count, they all contained invalid umasks\n");
+		return PAPI_ENOEVNT;
+	}
+
+  pe_ctl->num_events = count - skipped_events;
 
    /* actuall open the events */
    /* (why is this a separate function?) */
@@ -627,6 +815,7 @@ _peu_update_control_state( hwd_control_state_t *ctl,
       return ret;
    }
 
+   SUBDBG( "EXIT: PAPI_OK\n" );
    return PAPI_OK;
 }
 
@@ -637,29 +826,17 @@ _peu_update_control_state( hwd_control_state_t *ctl,
 /********************************************************************/
 
 
-/* set the domain. FIXME: perf_events allows per-event control of this. */
-/* we do not handle that yet.                                           */
-int
+/* set the domain. perf_events allows per-event control of this, papi allows it to be set at the event level or at the event set level. */
+/* this will set the event set level domain values but they only get used if no event level domain mask (u= or k=) was specified. */
+static int
 _peu_set_domain( hwd_control_state_t *ctl, int domain)
 {
-
-   int i;
    pe_control_t *pe_ctl = ( pe_control_t *) ctl;
 
    SUBDBG("old control domain %d, new domain %d\n",
 	  pe_ctl->domain,domain);
 
    pe_ctl->domain = domain;
-
-   /* Force the domain on all events */
-   for( i = 0; i < pe_ctl->num_events; i++ ) {
-      pe_ctl->events[i].attr.exclude_user =
-	                !( pe_ctl->domain & PAPI_DOM_USER );
-      pe_ctl->events[i].attr.exclude_kernel =
-			!( pe_ctl->domain & PAPI_DOM_KERNEL );
-      pe_ctl->events[i].attr.exclude_hv =
-			!( pe_ctl->domain & PAPI_DOM_SUPERVISOR );
-   }
    return PAPI_OK;
 }
 
@@ -737,6 +914,8 @@ int
 _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 	       long long **events, int flags )
 {
+    SUBDBG("ENTER: ctx: %p, ctl: %p, events: %p, flags: %#x\n", ctx, ctl, events, flags);
+
    ( void ) flags;			 /*unused */
    int i, ret = -1;
    /* pe_context_t *pe_ctx = ( pe_context_t *) ctx; */ 
@@ -757,18 +936,20 @@ _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 		    sizeof ( papi_pe_buffer ) );
          if ( ret == -1 ) {
 	    PAPIERROR("read returned an error: ", strerror( errno ));
+       SUBDBG("EXIT: PAPI_ESYS\n");
 	    return PAPI_ESYS;
 	 }
 
 	 /* We should read 3 64-bit values from the counter */
 	 if (ret<(signed)(3*sizeof(long long))) {
 	    PAPIERROR("Error!  short read!\n");
+       SUBDBG("EXIT: PAPI_ESYS\n");
 	    return PAPI_ESYS;
 	 }
 
          SUBDBG("read: fd: %2d, tid: %ld, cpu: %d, ret: %d\n",
 	        pe_ctl->events[i].event_fd,
-		(long)pe_ctl->tid, pe_ctl->cpu, ret);
+		(long)pe_ctl->tid, pe_ctl->events[i].cpu, ret);
          SUBDBG("read: %lld %lld %lld\n",papi_pe_buffer[0],
 	        papi_pe_buffer[1],papi_pe_buffer[2]);
 
@@ -813,6 +994,7 @@ _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 		    sizeof ( papi_pe_buffer ) );
          if ( ret == -1 ) {
 	    PAPIERROR("read returned an error: ", strerror( errno ));
+       SUBDBG("EXIT: PAPI_ESYS\n");
 	    return PAPI_ESYS;
 	 }
 
@@ -821,13 +1003,14 @@ _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 	    PAPIERROR("Error!  short read!\n");
 	    PAPIERROR("read: fd: %2d, tid: %ld, cpu: %d, ret: %d\n",
 		   pe_ctl->events[i].event_fd,
-		   (long)pe_ctl->tid, pe_ctl->cpu, ret);
+		   (long)pe_ctl->tid, pe_ctl->events[i].cpu, ret);
+       SUBDBG("EXIT: PAPI_ESYS\n");
 	    return PAPI_ESYS;
 	 }
 
          SUBDBG("read: fd: %2d, tid: %ld, cpu: %d, ret: %d\n",
 	        pe_ctl->events[i].event_fd, (long)pe_ctl->tid,
-		pe_ctl->cpu, ret);
+		pe_ctl->events[i].cpu, ret);
          SUBDBG("read: %lld\n",papi_pe_buffer[0]);
 
 	 pe_ctl->counts[i] = papi_pe_buffer[0];
@@ -848,6 +1031,7 @@ _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 
       if ( ret == -1 ) {
 	 PAPIERROR("read returned an error: ", strerror( errno ));
+       SUBDBG("EXIT: PAPI_ESYS\n");
 	 return PAPI_ESYS;
       }
 
@@ -855,12 +1039,13 @@ _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
       /* num_events more 64-bit values that hold the counts */
       if (ret<(signed)((1+pe_ctl->num_events)*sizeof(long long))) {
 	 PAPIERROR("Error! short read!\n");
+       SUBDBG("EXIT: PAPI_ESYS\n");
 	 return PAPI_ESYS;
       }
 
       SUBDBG("read: fd: %2d, tid: %ld, cpu: %d, ret: %d\n",
 	     pe_ctl->events[0].event_fd,
-	     (long)pe_ctl->tid, pe_ctl->cpu, ret);
+	     (long)pe_ctl->tid, pe_ctl->events[0].cpu, ret);
       {
 	 int j;
 	 for(j=0;j<ret/8;j++) {
@@ -871,11 +1056,12 @@ _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
       /* Make sure the kernel agrees with how many events we have */
       if (papi_pe_buffer[0]!=pe_ctl->num_events) {
 	 PAPIERROR("Error!  Wrong number of events!\n");
+       SUBDBG("EXIT: PAPI_ESYS\n");
 	 return PAPI_ESYS;
       }
 
       /* put the count values in their proper location */
-      for(i=0;i<papi_pe_buffer[0];i++) {
+      for(i=0;i<pe_ctl->num_events;i++) {
          pe_ctl->counts[i] = papi_pe_buffer[1+i];
       }
    }
@@ -883,6 +1069,7 @@ _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
    /* point PAPI to the values we read */
    *events = pe_ctl->counts;
 
+   SUBDBG("EXIT: PAPI_OK\n");
    return PAPI_OK;
 }
 
@@ -897,7 +1084,7 @@ _peu_start( hwd_context_t *ctx, hwd_control_state_t *ctl )
    pe_control_t *pe_ctl = ( pe_control_t *) ctl;
 
    /* Reset the counters first.  Is this necessary? */
-   ret = _pe_reset( pe_ctx, pe_ctl );
+   ret = _peu_reset( pe_ctx, pe_ctl );
    if ( ret ) {
       return ret;
    }
@@ -1011,8 +1198,9 @@ _peu_ctl( hwd_context_t *ctx, int code, _papi_int_option_t *option )
       case PAPI_DOMAIN:
 	   pe_ctl = ( pe_control_t *) ( option->domain.ESI->ctl_state );
 
-	   /* looks like we are allowed, so set counting domain */
-	   return _pe_set_domain( pe_ctl, option->domain.domain );
+	   /* looks like we are allowed, so set event set level counting domains */
+       pe_ctl->domain = option->domain.domain;
+	   return PAPI_OK;
 
       case PAPI_GRANUL:
 	   pe_ctl = (pe_control_t *) ( option->granularity.ESI->ctl_state );
