@@ -169,8 +169,11 @@ int main (int argc, char **argv)
 	  test_fail( __FILE__, __LINE__,
              "Error getting event info\n",retval);
 	}
-	
-	strncpy(units[num_events],evinfo.units,PAPI_MIN_STR_LEN);
+
+	strncpy(units[num_events],evinfo.units,sizeof(units[0])-1);
+	// buffer must be null terminated to safely use strstr operation on it below
+	units[num_events][sizeof(units[0])-1] = '\0';
+
 	data_type[num_events] = evinfo.data_type;
 
         retval = PAPI_add_event( EventSet, code );
@@ -232,7 +235,7 @@ int main (int argc, char **argv)
 
 		for(i=0;i<num_events;i++) {
 		   if (strstr(event_names[i],"ENERGY_CNT")) {
-			  printf("%-40s%12lld\t%#08x\n", event_names[i], values[i], values[i]);
+			  printf("%-40s%12lld\t%#08llx\n", event_names[i], values[i], values[i]);
 		   }
 		}
 
@@ -260,7 +263,7 @@ int main (int argc, char **argv)
 		for(i=0;i<num_events;i++) {
 		   if (!strstr(event_names[i],"ENERGY")) {
 			  if (data_type[i] == PAPI_DATATYPE_UINT64) {
-				printf("%-40s%12lld\t%#08x\n", event_names[i], values[i], values[i]);
+				printf("%-40s%12lld\t%#08llx\n", event_names[i], values[i], values[i]);
 			  }
 		   }
 		}
@@ -274,7 +277,7 @@ int main (int argc, char **argv)
 	
 	for(i=0;i<num_events;i++) {
 		if (strstr(event_names[i],"ENERGY_CNT")) {
-			if (max_value < values[i]) {
+			if (max_value < (unsigned) values[i]) {
 				max_value = values[i];
 		  	}
 		}
@@ -327,7 +330,7 @@ int main (int argc, char **argv)
 
 		for(i=0;i<num_events;i++) {
 		   if (strstr(event_names[i],"ENERGY_CNT")) {
-			  printf("%-40s%12lld\t%#08x\n", event_names[i], values[i], values[i]);
+			  printf("%-40s%12lld\t%#08llx\n", event_names[i], values[i], values[i]);
 		   }
 		}
 	}
