@@ -54,30 +54,17 @@ static const intel_x86_umask_t slm_uops_retired[]={
      .ucode = 0x0100,
      .uflags= INTEL_X86_NCOMBO,
    },
-   { .uname  = "X87",
-     .udesc  = "Micro-ops retired that used X87 hardware",
-     .ucode = 0x0200,
-     .uflags= INTEL_X86_NCOMBO,
-   },
-   { .uname  = "MUL",
-     .udesc  = "Micro-ops retired that used MUL hardware",
-     .ucode = 0x0400,
-     .uflags= INTEL_X86_NCOMBO,
-   },
-   { .uname  = "DIV",
-     .udesc  = "Micro-ops retired that used DIV hardware",
-     .ucode = 0x0800,
-     .uflags= INTEL_X86_NCOMBO,
-   },
    { .uname  = "STALLED_CYCLES",
      .udesc  = "Cycles no micro-ops retired",
      .ucode = 0x1000 | INTEL_X86_MOD_INV | (0x1 << INTEL_X86_CMASK_BIT),
      .uflags= INTEL_X86_NCOMBO,
+    .modhw  = _INTEL_X86_ATTR_I | _INTEL_X86_ATTR_C,
    },
    { .uname  = "STALLS",
      .udesc  = "Periods no micro-ops retired",
      .ucode = 0x1000 | INTEL_X86_MOD_EDGE | INTEL_X86_MOD_INV | (0x1 << INTEL_X86_CMASK_BIT),
      .uflags= INTEL_X86_NCOMBO,
+     .modhw  = _INTEL_X86_ATTR_I | _INTEL_X86_ATTR_C | _INTEL_X86_ATTR_E,
    },
 };
 
@@ -167,7 +154,7 @@ static const intel_x86_umask_t slm_br_inst_retired[]={
    },
    { .uname  = "RETURN",
      .udesc  = "Near ret instructions retired (Precise Event)",
-     .ucode = 0xc00,
+     .ucode = 0xf700,
      .uflags= INTEL_X86_NCOMBO | INTEL_X86_PEBS,
    },
    { .uname  = "NON_RETURN_IND",
@@ -200,16 +187,6 @@ static const intel_x86_umask_t slm_baclears[]={
      .ucode = 0x100,
      .uflags= INTEL_X86_DFL | INTEL_X86_NCOMBO,
    },
-   { .uname  = "INDIRECT",
-     .udesc  = "Number of baclears for indirect branches",
-     .ucode = 0x200,
-     .uflags= INTEL_X86_NCOMBO,
-   },
-   { .uname  = "UNCOND",
-     .udesc  = "Number of baclears for unconditional branches",
-     .ucode = 0x400,
-     .uflags= INTEL_X86_NCOMBO,
-   },
    { .uname  = "RETURN",
      .udesc  = "Number of baclears for return branches",
      .ucode = 0x800,
@@ -230,13 +207,13 @@ static const intel_x86_umask_t slm_cpu_clk_unhalted[]={
    },
    { .uname  = "BUS",
      .udesc  = "Bus cycles when core is not halted. This event can give a measurement of the elapsed time. This events has a constant ratio with CPU_CLK_UNHALTED:REF event, which is the maximum bus to processor frequency ratio",
-     .uequiv = "REF_P",
-     .ucode = 0x100,
-     .uflags= INTEL_X86_NCOMBO,
+     .uequiv = "REF",
+     .ucode  = 0x100,
+     .uflags = INTEL_X86_NCOMBO,
    },
-   { .uname  = "REF_P",
+   { .uname  = "REF",
      .udesc  = "Number of reference cycles that the core is not in a halted state. The core enters the halted state when it is running the HLT instruction. In mobile systems, the core frequency may change from time to time. This event is not affected by core frequency changes but counts as if the core is running a the same maximum frequency all the time",
-     .ucode = 0x200,
+     .ucode = 0x100,
      .uflags= INTEL_X86_NCOMBO,
    },
 };
@@ -280,31 +257,6 @@ static const intel_x86_umask_t slm_mem_uop_retired[]={
    },
 };
 
-static const intel_x86_umask_t slm_page_walks[]={
-   { .uname  = "D_SIDE_CYCLES",
-     .udesc  = "Number of cycles when a D-side page walk is in progress. Page walk duration divided by number of page walks is the average duration of page-walks",
-     .ucode = 0x100,
-     .uflags= INTEL_X86_NCOMBO,
-   },
-   { .uname  = "D_SIDE_WALKS",
-     .udesc  = "Number of D-side page walks",
-     .ucode = 0x100 | INTEL_X86_MOD_EDGE | (1ULL << INTEL_X86_CMASK_BIT),
-     .modhw = _INTEL_X86_ATTR_E |  _INTEL_X86_ATTR_C,
-     .uflags= INTEL_X86_NCOMBO,
-   },
-   { .uname  = "I_SIDE_CYCLES",
-     .udesc  = "Number of cycles when a I-side page walk is in progress. Page walk duration divided by number of page walks is the average duration of page-walks",
-     .ucode = 0x200,
-     .uflags= INTEL_X86_NCOMBO,
-   },
-   { .uname  = "I_SIDE_WALKS",
-     .udesc  = "Number of I-side page walks",
-     .ucode = 0x200 | INTEL_X86_MOD_EDGE | (1ULL << INTEL_X86_CMASK_BIT),
-     .modhw = _INTEL_X86_ATTR_E |  _INTEL_X86_ATTR_C,
-     .uflags= INTEL_X86_NCOMBO,
-   },
-};
-
 static const intel_x86_umask_t slm_llc_rqsts[]={
    { .uname  = "MISS",
      .udesc  = "Number of L2 cache misses",
@@ -512,7 +464,7 @@ static const intel_x86_umask_t slm_offcore_response[]={
    },
 };
 
-static const intel_x86_umask_t slm_br_misp_inst_retired[]={
+static const intel_x86_umask_t slm_br_misp_retired[]={
    { .uname  = "ALL_BRANCHES",
      .udesc  = "All mispredicted branches (Precise Event)",
      .uequiv = "ANY",
@@ -534,31 +486,16 @@ static const intel_x86_umask_t slm_br_misp_inst_retired[]={
      .ucode = 0xeb00,
      .uflags= INTEL_X86_NCOMBO | INTEL_X86_PEBS,
    },
-   { .uname  = "FAR",
-     .udesc  = "Number of mispredicted far branch instructions retired (Precise Event)",
-     .ucode  = 0xbf00,
-     .uflags = INTEL_X86_NCOMBO | INTEL_X86_PEBS,
-   },
    { .uname  = "RETURN",
      .udesc  = "Number of mispredicted return branch instructions retired (Precise Event)",
      .ucode = 0xf700,
      .uflags= INTEL_X86_NCOMBO | INTEL_X86_PEBS,
    },
-   { .uname  = "CALL",
-     .udesc  = "Number of mispredicted call branch instructions retired (Precise Event)",
-     .ucode = 0xf900,
-     .uflags= INTEL_X86_NCOMBO | INTEL_X86_PEBS,
-   },
    { .uname  = "IND_CALL",
      .udesc  = "Number of mispredicted indirect call branch instructions retired (Precise Event)",
      .ucode = 0xfb00,
      .uflags= INTEL_X86_NCOMBO | INTEL_X86_PEBS,
    },
-   { .uname  = "REL_CALL",
-     .udesc  = "Number of mispredicted relative call branch instructions retired (Precise Event)",
-     .ucode = 0xfd00,
-     .uflags= INTEL_X86_NCOMBO | INTEL_X86_PEBS,
-   },
    { .uname  = "TAKEN_JCC",
      .udesc  = "Number of mispredicted taken conditional branch instructions retired (Precise Event)",
      .ucode = 0xfe00,
@@ -568,6 +505,12 @@ static const intel_x86_umask_t slm_br_misp_inst_retired[]={
 
 static const intel_x86_umask_t slm_no_alloc_cycles[]={
    { .uname  = "ANY",
+     .udesc  = "Number of cycles when the front-end does not provide any instructions to be allocated for any reason",
+     .ucode  = 0x3f00,
+     .uequiv = "ALL",
+     .uflags = INTEL_X86_NCOMBO,
+   },
+   { .uname  = "ALL",
      .udesc  = "Number of cycles when the front-end does not provide any instructions to be allocated for any reason",
      .ucode = 0x3f00,
      .uflags= INTEL_X86_NCOMBO | INTEL_X86_DFL,
@@ -577,6 +520,21 @@ static const intel_x86_umask_t slm_no_alloc_cycles[]={
      .ucode = 0x5000,
      .uflags= INTEL_X86_NCOMBO,
    },
+   { .uname  = "MISPREDICTS",
+     .udesc  = "Number of cycles when no uops are allocated and the alloc pipe is stalled waiting for a mispredicted jump to retire",
+     .ucode = 0x400,
+     .uflags= INTEL_X86_NCOMBO,
+   },
+   { .uname  = "RAT_STALL",
+     .udesc  = "Number of cycles when no uops are allocated and a RAT stall is asserted",
+     .ucode = 0x2000,
+     .uflags= INTEL_X86_NCOMBO,
+   },
+   { .uname  = "ROB_FULL",
+     .udesc  = "Number of cycles when no uops are allocated and the ROB is full (less than 2 entries available)",
+     .ucode = 0x0100,
+     .uflags= INTEL_X86_NCOMBO,
+   },
 };
 
 static const intel_x86_umask_t slm_rs_full_stall[]={
@@ -584,27 +542,17 @@ static const intel_x86_umask_t slm_rs_full_stall[]={
      .udesc  = "Number of cycles when the allocation pipeline is stalled due to the RS for the MEC cluster is full",
      .ucode = 0x0100,
    },
-   { .uname  = "IEC_PORT0",
-     .udesc  = "Number of cycles when the allocation pipeline is stalled due to the RS for port 0 integer cluster is full",
-     .ucode = 0x0200,
-   },
-   { .uname  = "IEC_PORT1",
-     .udesc  = "Number of cycles when the allocation pipeline is stalled due to the RS for port 1 integer cluster is full",
-     .ucode = 0x0400,
-   },
-   { .uname  = "FPC_PORT0",
-     .udesc  = "Number of cycles when the allocation pipeline is stalled due to the RS for port 0 floating-pointer cluster is full",
-     .ucode = 0x0800,
-   },
-   { .uname  = "FPC_PORT1",
-     .udesc  = "Number of cycles when the allocation pipeline is stalled due to the RS for port 1 floating-pointer cluster is full",
-     .ucode = 0x1000,
-   },
-   { .uname  = "ANY",
+   { .uname  = "ALL",
      .udesc  = "Number of cycles when the allocation pipeline is stalled due any one of the RS being full",
      .ucode = 0x1f00,
      .uflags= INTEL_X86_NCOMBO | INTEL_X86_DFL,
    },
+   { .uname  = "ANY",
+     .udesc  = "Number of cycles when the allocation pipeline is stalled due any one of the RS being full",
+     .ucode  = 0x1f00,
+     .uequiv = "ALL",
+     .uflags = INTEL_X86_NCOMBO,
+   },
 };
 
 static const intel_x86_umask_t slm_cycles_div_busy[]={
@@ -631,6 +579,54 @@ static const intel_x86_umask_t slm_decode_restriction[]={
    },
 };
 
+static const intel_x86_umask_t slm_fetch_stall[]={
+   { .uname  = "ICACHE_FILL_PENDING_CYCLES",
+     .udesc  = "Number of cycles the NIP stalls because of an icache miss. This is a cumulative count of cycles the NIP stalled for all icache misses",
+     .ucode = 0x0400,
+     .uflags= INTEL_X86_NCOMBO | INTEL_X86_DFL,
+   },
+};
+
+static const intel_x86_umask_t slm_core_reject_l2q[]={
+   { .uname  = "ALL",
+     .udesc  = "Number of requests that were not accepted into the L2Q because the L2Q was FULL",
+     .ucode  = 0x0000,
+     .uflags = INTEL_X86_DFL,
+   },
+};
+
+static const intel_x86_umask_t slm_page_walks[]={
+   { .uname  = "CYCLES",
+     .udesc  = "Total cycles for all the page walks. (I-side and D-side)",
+     .ucode  = 0x0300,
+     .uflags= INTEL_X86_NCOMBO,
+   },
+   { .uname  = "WALKS",
+     .udesc  = "Total number of page walks. (I-side and D-side)",
+     .ucode  = 0x0300 | INTEL_X86_MOD_EDGE,
+     .uequiv = "D_SIDE_WALKS:I_SIDE_WALKS",
+     .uflags = INTEL_X86_NCOMBO,
+   },
+   { .uname  = "D_SIDE_CYCLES",
+     .udesc  = "Number of cycles when a D-side page walk is in progress",
+     .ucode  = 0x0100,
+   },
+   { .uname  = "D_SIDE_WALKS",
+     .udesc  = "Number of D-side page walks",
+     .ucode  = 0x0100 | INTEL_X86_MOD_EDGE,
+     .uequiv = "D_SIDE_CYCLES:e",
+   },
+   { .uname  = "I_SIDE_CYCLES",
+     .udesc  = "Number of cycles when a I-side page walk is in progress",
+     .ucode  = 0x0200,
+   },
+   { .uname  = "I_SIDE_WALKS",
+     .udesc  = "Number of I-side page walks",
+     .ucode  = 0x0200 | INTEL_X86_MOD_EDGE,
+     .uequiv = "I_SIDE_CYCLES:e",
+   },
+};
+
 static const intel_x86_entry_t intel_slm_pe[]={
 { .name   = "UNHALTED_CORE_CYCLES",
   .desc   = "Unhalted core cycles",
@@ -693,7 +689,7 @@ static const intel_x86_entry_t intel_slm_pe[]={
 },
 { .name   = "MISPREDICTED_BRANCH_RETIRED",
   .desc   = "Mispredicted branch instruction retired",
-  .equiv  = "BR_MISP_INST_RETIRED",
+  .equiv  = "BR_MISP_RETIRED",
   .modmsk = INTEL_V2_ATTRS,
   .cntmsk = 0x3,
   .code = 0xc5,
@@ -792,15 +788,26 @@ static const intel_x86_entry_t intel_slm_pe[]={
   .ngrp = 1,
   .umasks = slm_br_inst_retired,
 },
-{ .name   = "BR_MISP_INST_RETIRED",
-  .desc   = "Mispredicted retired branch instructions",
+{ .name   = "BR_MISP_RETIRED",
+  .desc   = "Mispredicted retired branch instructions (Precise Event)",
   .modmsk = INTEL_V2_ATTRS,
   .cntmsk = 0x3,
   .code = 0xc5,
   .flags= INTEL_X86_PEBS,
-  .numasks = LIBPFM_ARRAY_SIZE(slm_br_misp_inst_retired),
+  .numasks = LIBPFM_ARRAY_SIZE(slm_br_misp_retired),
   .ngrp = 1,
-  .umasks = slm_br_misp_inst_retired,
+  .umasks = slm_br_misp_retired,
+},
+{ .name   = "BR_MISP_INST_RETIRED", /* for backward compatibility with older version */
+  .desc   = "Mispredicted retired branch instructions (Precise Event)",
+  .modmsk = INTEL_V2_ATTRS,
+  .equiv  = "BR_MISP_RETIRED",
+  .cntmsk = 0x3,
+  .code = 0xc5,
+  .flags= INTEL_X86_PEBS,
+  .numasks = LIBPFM_ARRAY_SIZE(slm_br_misp_retired),
+  .ngrp = 1,
+  .umasks = slm_br_misp_retired,
 },
 { .name   = "MS_DECODED",
   .desc   = "MS decoder",
@@ -848,20 +855,14 @@ static const intel_x86_entry_t intel_slm_pe[]={
   .ngrp = 1,
   .umasks = slm_mem_uop_retired,
 },
-{ .name   = "PAGE_WALKS",
-  .desc   = "Number of page-walks executed",
-  .modmsk = INTEL_V2_ATTRS,
-  .cntmsk = 0x3,
-  .code = 0x5,
-  .numasks = LIBPFM_ARRAY_SIZE(slm_page_walks),
-  .ngrp = 1,
-  .umasks = slm_page_walks,
-},
-{ .name   = "CORE_REJECT",
+{ .name   = "CORE_REJECT_L2Q",
   .desc   = "Demand and L1 prefetcher requests rejected by L2",
   .modmsk = INTEL_V2_ATTRS,
   .cntmsk = 0x3,
   .code = 0x31,
+  .numasks = LIBPFM_ARRAY_SIZE(slm_core_reject_l2q),
+  .ngrp = 1,
+  .umasks = slm_core_reject_l2q,
 },
 { .name   = "REHABQ",
   .desc   = "Memory reference queue",
@@ -873,6 +874,24 @@ static const intel_x86_entry_t intel_slm_pe[]={
   .ngrp = 1,
   .umasks = slm_rehabq,
 },
+{ .name   = "FETCH_STALL",
+  .desc   = "Fetch stalls",
+  .modmsk = INTEL_V2_ATTRS,
+  .cntmsk = 0x3,
+  .code = 0x86,
+  .numasks = LIBPFM_ARRAY_SIZE(slm_fetch_stall),
+  .ngrp = 1,
+  .umasks = slm_fetch_stall,
+},
+{ .name   = "PAGE_WALKS",
+  .desc   = "Page walker",
+  .modmsk = INTEL_V2_ATTRS,
+  .cntmsk = 0x3,
+  .code = 0x5,
+  .numasks = LIBPFM_ARRAY_SIZE(slm_page_walks),
+  .ngrp = 1,
+  .umasks = slm_page_walks,
+},
 { .name   = "OFFCORE_RESPONSE_0",
   .desc   = "Offcore response event (must provide at least one request type and either any_response or any combination of supplier + snoop)",
   .modmsk = INTEL_V2_ATTRS,
