@@ -100,6 +100,7 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&intel_hsw_support,
 	&intel_hsw_ep_support,
 	&intel_bdw_support,
+	&intel_skl_support,
 	&intel_rapl_support,
 	&intel_snbep_unc_cb0_support,
 	&intel_snbep_unc_cb1_support,
@@ -158,6 +159,47 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&intel_ivbep_unc_r3qpi1_support,
 	&intel_ivbep_unc_r3qpi2_support,
 	&intel_ivbep_unc_irp_support,
+	&intel_hswep_unc_cb0_support,
+	&intel_hswep_unc_cb1_support,
+	&intel_hswep_unc_cb2_support,
+	&intel_hswep_unc_cb3_support,
+	&intel_hswep_unc_cb4_support,
+	&intel_hswep_unc_cb5_support,
+	&intel_hswep_unc_cb6_support,
+	&intel_hswep_unc_cb7_support,
+	&intel_hswep_unc_cb8_support,
+	&intel_hswep_unc_cb9_support,
+	&intel_hswep_unc_cb10_support,
+	&intel_hswep_unc_cb11_support,
+	&intel_hswep_unc_cb12_support,
+	&intel_hswep_unc_cb13_support,
+	&intel_hswep_unc_cb14_support,
+	&intel_hswep_unc_cb15_support,
+	&intel_hswep_unc_cb16_support,
+	&intel_hswep_unc_cb17_support,
+	&intel_hswep_unc_ha0_support,
+	&intel_hswep_unc_ha1_support,
+	&intel_hswep_unc_imc0_support,
+	&intel_hswep_unc_imc1_support,
+	&intel_hswep_unc_imc2_support,
+	&intel_hswep_unc_imc3_support,
+	&intel_hswep_unc_imc4_support,
+	&intel_hswep_unc_imc5_support,
+	&intel_hswep_unc_imc6_support,
+	&intel_hswep_unc_imc7_support,
+	&intel_hswep_unc_pcu_support,
+	&intel_hswep_unc_qpi0_support,
+	&intel_hswep_unc_qpi1_support,
+	&intel_hswep_unc_sb0_support,
+	&intel_hswep_unc_sb1_support,
+	&intel_hswep_unc_sb2_support,
+	&intel_hswep_unc_sb3_support,
+	&intel_hswep_unc_ubo_support,
+	&intel_hswep_unc_r2pcie_support,
+	&intel_hswep_unc_r3qpi0_support,
+	&intel_hswep_unc_r3qpi1_support,
+	&intel_hswep_unc_r3qpi2_support,
+	&intel_hswep_unc_irp_support,
 	&intel_x86_arch_support, /* must always be last for x86 */
 #endif
 
@@ -179,6 +221,8 @@ static pfmlib_pmu_t *pfmlib_pmus[]=
 	&power7_support,
 	&power8_support,
 	&torrent_support,
+    &powerpc_nest_mcs_read_support,
+    &powerpc_nest_mcs_write_support,
 #endif
 
 #ifdef CONFIG_PFMLIB_ARCH_SPARC
@@ -751,29 +795,29 @@ pfm_initialize(void)
 	int ret;
 	/*
 	 * not atomic
+	 * if initialization already done, then reurn previous return value
 	 */
 	if (pfm_cfg.initdone)
-		return PFM_SUCCESS;
+		return pfm_cfg.initret;
 
 	/*
 	 * generic sanity checks
 	 */
 	if (PFM_PMU_MAX & (~PFMLIB_PMU_MASK)) {
 		DPRINT("PFM_PMU_MAX exceeds PFMLIB_PMU_MASK\n");	
-		return PFM_ERR_NOTSUPP;
+		ret = PFM_ERR_NOTSUPP;
+	} else {
+
+		pfmlib_init_env();
+
+		/* must be done before pfmlib_init_pmus() */
+		pfmlib_init_os();
+
+		ret = pfmlib_init_pmus();
 	}
 
-	pfmlib_init_env();
-
-	/* must be done before pfmlib_init_pmus() */
-	pfmlib_init_os();
-
-	ret = pfmlib_init_pmus();
-	if (ret != PFM_SUCCESS)
-		return ret;
-
-
 	pfm_cfg.initdone = 1;
+	pfm_cfg.initret  = ret;
 
 	return ret;
 }
