@@ -167,6 +167,7 @@ typedef struct {
 
 typedef struct {
 	int	initdone;
+	int	initret; /* initial return value from pfm_initialize() */
 	int	verbose;
 	int	debug;
 	int	inactive;
@@ -175,7 +176,7 @@ typedef struct {
 	FILE 	*fp;	/* verbose and debug file descriptor, default stderr or PFMLIB_DEBUG_STDOUT */
 } pfmlib_config_t;	
 
-#define PFMLIB_INITIALIZED()	(pfm_cfg.initdone)
+#define PFMLIB_INITIALIZED()	(pfm_cfg.initdone && pfm_cfg.initret == PFM_SUCCESS)
 
 extern pfmlib_config_t pfm_cfg;
 
@@ -251,6 +252,7 @@ extern pfmlib_pmu_t intel_ivb_ep_support;
 extern pfmlib_pmu_t intel_hsw_support;
 extern pfmlib_pmu_t intel_hsw_ep_support;
 extern pfmlib_pmu_t intel_bdw_support;
+extern pfmlib_pmu_t intel_skl_support;
 extern pfmlib_pmu_t intel_rapl_support;
 extern pfmlib_pmu_t intel_snbep_unc_cb0_support;
 extern pfmlib_pmu_t intel_snbep_unc_cb1_support;
@@ -307,6 +309,47 @@ extern pfmlib_pmu_t intel_ivbep_unc_r3qpi0_support;
 extern pfmlib_pmu_t intel_ivbep_unc_r3qpi1_support;
 extern pfmlib_pmu_t intel_ivbep_unc_r3qpi2_support;
 extern pfmlib_pmu_t intel_ivbep_unc_irp_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb0_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb1_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb2_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb3_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb4_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb5_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb6_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb7_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb8_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb9_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb10_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb11_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb12_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb13_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb14_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb15_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb16_support;
+extern pfmlib_pmu_t intel_hswep_unc_cb17_support;
+extern pfmlib_pmu_t intel_hswep_unc_ha0_support;
+extern pfmlib_pmu_t intel_hswep_unc_ha1_support;
+extern pfmlib_pmu_t intel_hswep_unc_imc0_support;
+extern pfmlib_pmu_t intel_hswep_unc_imc1_support;
+extern pfmlib_pmu_t intel_hswep_unc_imc2_support;
+extern pfmlib_pmu_t intel_hswep_unc_imc3_support;
+extern pfmlib_pmu_t intel_hswep_unc_imc4_support;
+extern pfmlib_pmu_t intel_hswep_unc_imc5_support;
+extern pfmlib_pmu_t intel_hswep_unc_imc6_support;
+extern pfmlib_pmu_t intel_hswep_unc_imc7_support;
+extern pfmlib_pmu_t intel_hswep_unc_pcu_support;
+extern pfmlib_pmu_t intel_hswep_unc_qpi0_support;
+extern pfmlib_pmu_t intel_hswep_unc_qpi1_support;
+extern pfmlib_pmu_t intel_hswep_unc_sb0_support;
+extern pfmlib_pmu_t intel_hswep_unc_sb1_support;
+extern pfmlib_pmu_t intel_hswep_unc_sb2_support;
+extern pfmlib_pmu_t intel_hswep_unc_sb3_support;
+extern pfmlib_pmu_t intel_hswep_unc_ubo_support;
+extern pfmlib_pmu_t intel_hswep_unc_r2pcie_support;
+extern pfmlib_pmu_t intel_hswep_unc_r3qpi0_support;
+extern pfmlib_pmu_t intel_hswep_unc_r3qpi1_support;
+extern pfmlib_pmu_t intel_hswep_unc_r3qpi2_support;
+extern pfmlib_pmu_t intel_hswep_unc_irp_support;
 extern pfmlib_pmu_t intel_knc_support;
 extern pfmlib_pmu_t intel_slm_support;
 extern pfmlib_pmu_t power4_support;
@@ -318,6 +361,8 @@ extern pfmlib_pmu_t power6_support;
 extern pfmlib_pmu_t power7_support;
 extern pfmlib_pmu_t power8_support;
 extern pfmlib_pmu_t torrent_support;
+extern pfmlib_pmu_t powerpc_nest_mcs_read_support;
+extern pfmlib_pmu_t powerpc_nest_mcs_write_support;
 extern pfmlib_pmu_t sparc_support;
 extern pfmlib_pmu_t sparc_ultra12_support;
 extern pfmlib_pmu_t sparc_ultra3_support;
