@@ -50,7 +50,7 @@ static int _linux_init_locks(void) {
    return PAPI_OK;
 }
 
-	
+
 int
 _linux_detect_hypervisor(char *virtual_vendor_name) {
 
@@ -61,7 +61,7 @@ _linux_detect_hypervisor(char *virtual_vendor_name) {
 #else
 	(void) virtual_vendor_name;
 #endif
-	
+
 	return retval;
 }
 
@@ -167,161 +167,301 @@ path_exist( const char *path, ... )
 	return access( pathbuf, F_OK ) == 0;
 }
 
+static int
+decode_cpuinfo_x86( FILE *f, PAPI_hw_info_t *hwinfo )
+{
+	int tmp;
+	unsigned int strSize;
+	char maxargs[PAPI_HUGE_STR_LEN], *t, *s;
+
+	/* Stepping */
+	rewind( f );
+	s = search_cpu_info( f, "stepping", maxargs );
+	if ( s ) {
+		sscanf( s + 1, "%d", &tmp );
+		hwinfo->revision = ( float ) tmp;
+		hwinfo->cpuid_stepping = tmp;
+	}
+
+	/* Model Name */
+	rewind( f );
+	s = search_cpu_info( f, "model name", maxargs );
+	strSize = sizeof(hwinfo->model_string);
+	if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
+		*t = '\0';
+		if (strlen(s+2) >= strSize-1) {
+			s[strSize+1] = '\0';
+		}
+		strcpy( hwinfo->model_string, s + 2 );
+	}
+
+	/* Family */
+	rewind( f );
+	s = search_cpu_info( f, "cpu family", maxargs );
+	if ( s ) {
+		sscanf( s + 1, "%d", &tmp );
+		hwinfo->cpuid_family = tmp;
+	}
+
+
+	/* CPU Model */
+	rewind( f );
+	s = search_cpu_info( f, "model", maxargs );
+	if ( s ) {
+		sscanf( s + 1, "%d", &tmp );
+		hwinfo->model = tmp;
+		hwinfo->cpuid_model = tmp;
+	}
+
+	return PAPI_OK;
+}
+
+static int
+decode_cpuinfo_power(FILE *f, PAPI_hw_info_t *hwinfo )
+{
+
+	int tmp;
+	unsigned int strSize;
+	char maxargs[PAPI_HUGE_STR_LEN], *t, *s;
+
+	/* Revision */
+	rewind( f );
+	s = search_cpu_info( f, "revision", maxargs );
+	if ( s ) {
+		sscanf( s + 1, "%d", &tmp );
+		hwinfo->revision = ( float ) tmp;
+		hwinfo->cpuid_stepping = tmp;
+	}
+
+       /* Model Name */
+	rewind( f );
+	s = search_cpu_info( f, "model", maxargs );
+	strSize = sizeof(hwinfo->model_string);
+	if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
+		*t = '\0';
+		if (strlen(s+2) >= strSize-1) {
+			s[strSize+1] = '\0';
+		}
+		strcpy( hwinfo->model_string, s + 2 );
+	}
+
+	return PAPI_OK;
+}
+
+
+
+static int
+decode_cpuinfo_arm(FILE *f, PAPI_hw_info_t *hwinfo )
+{
+
+	int tmp;
+	unsigned int strSize;
+	char maxargs[PAPI_HUGE_STR_LEN], *t, *s;
+
+	/* revision */
+	rewind( f );
+	s = search_cpu_info( f, "CPU revision", maxargs );
+	if ( s ) {
+		sscanf( s + 1, "%d", &tmp );
+		hwinfo->revision = ( float ) tmp;
+		/* For compatability with old PAPI */
+		hwinfo->model = tmp;
+	}
+
+       /* Model Name */
+	rewind( f );
+	s = search_cpu_info( f, "model name", maxargs );
+	strSize = sizeof(hwinfo->model_string);
+	if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
+		*t = '\0';
+		if (strlen(s+2) >= strSize-1) {
+			s[strSize+1] = '\0';
+		}
+		strcpy( hwinfo->model_string, s + 2 );
+	}
+
+	/* Architecture (ARMv6, ARMv7, ARMv8, etc.) */
+	/* Note the Raspberry Pi lies in the CPU architecture line */
+	/* (it's ARMv6 not ARMv7)                                  */
+	/* So we should actually get the value from the            */
+	/*	Processor/ model name line                         */
+	rewind( f );
+	s = search_cpu_info( f, "CPU architecture", maxargs );
+	if ( s ) {
+
+		if (strstr(s,"AArch64")) {
+			hwinfo->cpuid_family = 8;
+		}
+		else {
+			rewind( f );
+			s = search_cpu_info( f, "Processor", maxargs );
+			if (s) {
+				t=strchr(s,'(');
+				tmp=*(t+2)-'0';
+				hwinfo->cpuid_family = tmp;
+			}
+			else {
+				rewind( f );
+				s = search_cpu_info( f, "model name", maxargs );
+				if (s) {
+					t=strchr(s,'(');
+					tmp=*(t+2)-'0';
+					hwinfo->cpuid_family = tmp;
+				}
+			}
+		}
+	}
+
+	/* CPU Model */
+	rewind( f );
+	s = search_cpu_info( f, "CPU part", maxargs );
+	if ( s ) {
+		sscanf( s + 1, "%x", &tmp );
+		hwinfo->cpuid_model = tmp;
+	}
+
+	/* CPU Variant */
+	rewind( f );
+	s = search_cpu_info( f, "CPU variant", maxargs );
+	if ( s ) {
+		sscanf( s + 1, "%x", &tmp );
+		hwinfo->cpuid_stepping = tmp;
+	}
+
+	return PAPI_OK;
+
+}
+
+
 int
 _linux_get_cpu_info( PAPI_hw_info_t *hwinfo, int *cpuinfo_mhz )
 {
-    int tmp, retval = PAPI_OK;
-    unsigned int strSize;
-    char maxargs[PAPI_HUGE_STR_LEN], *t, *s;
-    float mhz = 0.0;
-    FILE *f;
+	int retval = PAPI_OK;
+	unsigned int strSize;
+	char maxargs[PAPI_HUGE_STR_LEN], *t, *s;
+	float mhz = 0.0;
+	FILE *f;
+	char cpuinfo_filename[]="/proc/cpuinfo";
 
-    if ( ( f = fopen( "/proc/cpuinfo", "r" ) ) == NULL ) {
-       PAPIERROR( "fopen(/proc/cpuinfo) errno %d", errno );
-       return PAPI_ESYS;
-    }
+	if ( ( f = fopen( cpuinfo_filename, "r" ) ) == NULL ) {
+		PAPIERROR( "fopen(/proc/cpuinfo) errno %d", errno );
+		return PAPI_ESYS;
+	}
 
-	/* All of this information maybe overwritten by the component */
+	/* All of this information may be overwritten by the component */
 
-        /* MHZ */
-    rewind( f );
-    s = search_cpu_info( f, "clock", maxargs );
-    if ( !s ) {
-       rewind( f );
-       s = search_cpu_info( f, "cpu MHz", maxargs );
-    }
-    if ( s ) {
-       sscanf( s + 1, "%f", &mhz );
-    }
-    *cpuinfo_mhz = mhz;
+	/***********************/
+	/* Attempt to find MHz */
+	/***********************/
+	rewind( f );
+	s = search_cpu_info( f, "clock", maxargs );
+	if ( !s ) {
+		rewind( f );
+		s = search_cpu_info( f, "cpu MHz", maxargs );
+	}
+	if ( s ) {
+		sscanf( s + 1, "%f", &mhz );
+	}
+	*cpuinfo_mhz = mhz;
 
-       /* Vendor Name and Vendor Code */
-    rewind( f );
-    s = search_cpu_info( f, "vendor_id", maxargs );
-    strSize = sizeof(hwinfo->vendor_string);
-    if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
-       *t = '\0';
-       if (strlen(s+2) >= strSize-1)     s[strSize+1] = '\0';
-       strcpy( hwinfo->vendor_string, s + 2 );
-    } else {
-       rewind( f );
-       s = search_cpu_info( f, "vendor", maxargs );
-       if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
-	  *t = '\0';
-     if (strlen(s+2) >= strSize-1)     s[strSize+1] = '\0';
-	  strcpy( hwinfo->vendor_string, s + 2 );
-       } else {
-	  rewind( f );
-	  s = search_cpu_info( f, "system type", maxargs );
-	  if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
-	     *t = '\0';
-	     s = strtok( s + 2, " " );
-        if (strlen(s) >= strSize-1)     s[strSize-1] = '\0';
-	     strcpy( hwinfo->vendor_string, s );
-	  } else {
-	     rewind( f );
-	     s = search_cpu_info( f, "platform", maxargs );
-	     if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
+	/*******************************/
+	/* Vendor Name and Vendor Code */
+	/*******************************/
+
+	/* First try to read "vendor_id" field */
+	/* Which is the most common field      */
+	hwinfo->vendor_string[0]=0;
+	rewind( f );
+	s = search_cpu_info( f, "vendor_id", maxargs );
+	strSize = sizeof(hwinfo->vendor_string);
+	if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
 		*t = '\0';
-	        s = strtok( s + 2, " " );
-		if ( ( strcasecmp( s, "pSeries" ) == 0 ) ||
-                    ( strcasecmp( s, "PowerNV" ) == 0 ) ||
-		     ( strcasecmp( s, "PowerMac" ) == 0 ) ) {
-		   strcpy( hwinfo->vendor_string, "IBM" );
+		if (strlen(s+2) >= strSize-1) {
+			s[strSize+1] = '\0';
 		}
-	     } else {
+		strcpy( hwinfo->vendor_string, s + 2 );
+	}
+
+	/* If not found, try "vendor" which seems to be Itanium specific */
+	if (!hwinfo->vendor_string[0]) {
+		rewind( f );
+		s = search_cpu_info( f, "vendor", maxargs );
+		if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
+			*t = '\0';
+			if (strlen(s+2) >= strSize-1) {
+				s[strSize+1] = '\0';
+			}
+			strcpy( hwinfo->vendor_string, s + 2 );
+		}
+	}
+
+	/* "system type" seems to be MIPS and Alpha */
+	if (!hwinfo->vendor_string[0]) {
+		rewind( f );
+		s = search_cpu_info( f, "system type", maxargs );
+		if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
+			*t = '\0';
+			s = strtok( s + 2, " " );
+			if (strlen(s) >= strSize-1) {
+				s[strSize-1] = '\0';
+			}
+			strcpy( hwinfo->vendor_string, s );
+		}
+	}
+
+	/* "platform" indicates Power */
+	if (!hwinfo->vendor_string[0]) {
+
+		rewind( f );
+		s = search_cpu_info( f, "platform", maxargs );
+		if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
+			*t = '\0';
+			s = strtok( s + 2, " " );
+			if ( ( strcasecmp( s, "pSeries" ) == 0 ) ||
+				( strcasecmp( s, "PowerNV" ) == 0 ) ||
+				( strcasecmp( s, "PowerMac" ) == 0 ) ) {
+				strcpy( hwinfo->vendor_string, "IBM" );
+			}
+		}
+	}
+
+	/* "CPU implementer" indicates ARM */
+	if (!hwinfo->vendor_string[0]) {
+
 		rewind( f );
 		s = search_cpu_info( f, "CPU implementer", maxargs );
 		if ( s ) {
-		   strcpy( hwinfo->vendor_string, "ARM" );
+			strcpy( hwinfo->vendor_string, "ARM" );
 		}
-	     }
-	  }
-       }
-    }
-
-    if ( strlen( hwinfo->vendor_string ) ) {
-       decode_vendor_string( hwinfo->vendor_string, &hwinfo->vendor );
-    }
-
-	/* Revision */
-    rewind( f );
-    s = search_cpu_info( f, "stepping", maxargs );
-    if ( s ) {
-       sscanf( s + 1, "%d", &tmp );
-       hwinfo->revision = ( float ) tmp;
-       hwinfo->cpuid_stepping = tmp;
-    } else {
-       rewind( f );
-       s = search_cpu_info( f, "revision", maxargs );
-       if ( s ) {
-	  sscanf( s + 1, "%d", &tmp );
-	  hwinfo->revision = ( float ) tmp;
-	  hwinfo->cpuid_stepping = tmp;
-       }
-    }
-
-       /* Model Name */
-    rewind( f );
-    s = search_cpu_info( f, "model name", maxargs );
-    strSize = sizeof(hwinfo->model_string);
-    if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
-       *t = '\0';
-       if (strlen(s+2) >= strSize-1)     s[strSize+1] = '\0';
-       strcpy( hwinfo->model_string, s + 2 );
-    } else {
-       rewind( f );
-       s = search_cpu_info( f, "family", maxargs );
-       if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
-	  *t = '\0';
-     if (strlen(s+2) >= strSize-1)     s[strSize+1] = '\0';
-	  strcpy( hwinfo->model_string, s + 2 );
-       } else {
-	  rewind( f );
-	  s = search_cpu_info( f, "cpu model", maxargs );
-	  if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
-	     *t = '\0';
-	     strtok( s + 2, " " );
-	     s = strtok( NULL, " " );
-        if (strlen(s) >= strSize-1)     s[strSize-1] = '\0';
-	     strcpy( hwinfo->model_string, s );
-	  } else {
-	     rewind( f );
-	     s = search_cpu_info( f, "cpu", maxargs );
-	     if ( s && ( t = strchr( s + 2, '\n' ) ) ) {
-		*t = '\0';
-		/* get just the first token */
-		s = strtok( s + 2, " " );
-	if (strlen(s) >= strSize-1)     s[strSize-1] = '\0';
-		strcpy( hwinfo->model_string, s );
-	     }
-	  }
-       }
-    }
-
-       /* Family */
-    rewind( f );
-    s = search_cpu_info( f, "family", maxargs );
-    if ( s ) {
-       sscanf( s + 1, "%d", &tmp );
-       hwinfo->cpuid_family = tmp;
-    } else {
-       rewind( f );
-       s = search_cpu_info( f, "cpu family", maxargs );
-       if ( s ) {
-	  sscanf( s + 1, "%d", &tmp );
-	  hwinfo->cpuid_family = tmp;
 	}
-    }
 
-	/* CPU Model */
-    rewind( f );
-    s = search_cpu_info( f, "model", maxargs );
-    if ( s ) {
-       sscanf( s + 1, "%d", &tmp );
-       hwinfo->model = tmp;
-       hwinfo->cpuid_model = tmp;
-    }
+
+	/* Decode the string to an implementer value */
+	if ( strlen( hwinfo->vendor_string ) ) {
+		decode_vendor_string( hwinfo->vendor_string, &hwinfo->vendor );
+	}
+
+	/**********************************************/
+	/* Provide more stepping/model/family numbers */
+	/**********************************************/
+
+	if ((hwinfo->vendor==PAPI_VENDOR_INTEL) ||
+		(hwinfo->vendor==PAPI_VENDOR_AMD)) {
+
+		decode_cpuinfo_x86(f,hwinfo);
+	}
+
+	if (hwinfo->vendor==PAPI_VENDOR_IBM) {
+
+		decode_cpuinfo_power(f,hwinfo);
+	}
+
+	if (hwinfo->vendor==PAPI_VENDOR_ARM) {
+
+		decode_cpuinfo_arm(f,hwinfo);
+	}
+
+
 
 
 	/* The following members are set using the same methodology */
