@@ -211,11 +211,26 @@ get_cycles( void )
 	return ret;
 }
 
+/************************/
+/* aarch64 get_cycles() */
+/************************/
+
+#elif defined(__aarch64__)
+static inline long long
+get_cycles( void )
+{
+	register unsigned long ret;
+
+	__asm__ __volatile__ ("isb; mrs %0, cntvct_el0" : "=r" (ret));
+
+	return ret;
+}
+
 /************************/
 /* POWER get_cycles()   */
 /************************/
 
-#elif (defined(__powerpc__) || defined(__arm__) || defined(__mips__) || defined(__aarch64__))
+#elif (defined(__powerpc__) || defined(__arm__) || defined(__mips__))
 /*
  * It's not possible to read the cycles from user space on ppc970.
  * There is a 64-bit time-base register (TBU|TBL), but its
