@@ -1929,7 +1929,10 @@ _papi_hwi_init_global( void )
 	      if (retval==PAPI_OK) {
 		if (_papi_hwd[i]->cmp_info.num_cntrs >
 		    _papi_hwd[i]->cmp_info.num_mpx_cntrs) {
-		  fprintf(stderr,"Warning!  num_cntrs is more than num_mpx_cntrs\n");
+		  fprintf(stderr,"Warning!  num_cntrs %d is more than num_mpx_cntrs %d for component %s\n",
+                        _papi_hwd[i]->cmp_info.num_cntrs,
+                        _papi_hwd[i]->cmp_info.num_mpx_cntrs,
+                        _papi_hwd[i]->cmp_info.name);
 		}
 
 	      }
@@ -2548,7 +2551,7 @@ _papi_hwi_get_native_event_info( unsigned int EventCode,
        /* clear the event info */
        memset( info, 0, sizeof ( PAPI_event_info_t ) );
        info->event_code = ( unsigned int ) EventCode;
-
+       info->component_index = (unsigned int) cidx;
        retval = _papi_hwd[cidx]->ntv_code_to_info( 
 			      _papi_hwi_eventcode_to_native(EventCode), info);
 
