@@ -87,11 +87,6 @@ done
 echo $LIST
 echo ""
 
-CUDA=`find Makefile | xargs grep cuda`;
-if [ "$CUDA" != "" ]; then
-  EXCLUDE="$EXCLUDE `grep -v -e '^#\|^$' run_tests_exclude_cuda.txt`"
-fi
-
 echo ""
 echo "The following test cases will NOT be run:";
 echo $EXCLUDE;
