@@ -1416,8 +1416,6 @@ init_intel_leaf2( PAPI_mh_info_t * mh_info , int *num_levels)
 	int size;						   /* size of the descriptor table */
 	int last_level = 0;				   /* how many levels in the cache hierarchy */
 
-	int need_leaf4=0;
-
 	/* All of Intel's cache info is in 1 call to cpuid
 	 * however it is a table lookup :(
 	 */
@@ -1459,7 +1457,6 @@ init_intel_leaf2( PAPI_mh_info_t * mh_info , int *num_levels)
 				if ( i ) {	 /* skip the low order byte in eax [0]; it's the count (see above) */
 				   if ( reg.descrip[i] == 0xff ) {
 				      MEMDBG("Warning! PAPI x86_cache: must implement cpuid leaf 4\n");
-				      need_leaf4=1;
 				      return PAPI_ENOSUPP;
 				      /* we might continue instead */
 				      /* in order to get TLB info  */
@@ -1480,9 +1477,6 @@ init_intel_leaf2( PAPI_mh_info_t * mh_info , int *num_levels)
 early_exit:
 	MEMDBG( "# of Levels: %d\n", last_level );
 	*num_levels=last_level;
-	if (need_leaf4) {
-	   return PAPI_ENOSUPP;
-	}
 	return PAPI_OK;
 }
 
